#!/bin/sh
# File : swig-sources-regen.sh           I. Henry        17 October 2001
#                                        Last revised:   2 March 2006
#
# script for making SWIG generated source code 
#_______________________________________________________________________________
# wfdb-swig: SWIG (www.swig.org) wrappers for the WFDB library. Allows for
# reading and writing annotated waveforms (time series data) from a variety of
# computer languages.
#
# Copyright (C) 2005 Isaac C. Henry
#
# This library is free software; you can redistribute it and/or modify it under
# the terms of the GNU Library General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option) any
# later version.
#
# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
# more details.
#
# You should have received a copy of the GNU Library General Public License
# along with this library; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# You may contact the author by e-mail (ihenry@physionet.org) or postal mail
# (MIT Room E25-505A, Cambridge, MA 02139 USA).  For updates to this software,
# please visit PhysioNet (http://www.physionet.org/).
#_______________________________________________________________________________

SWIG=/usr/bin/swig
INCDIR=-I/usr/include
WFDB_JAVA=wfdb-java
WFDB_PERL=wfdb-perl
WFDB_PYTHON=wfdb-python
WFDB_CSHARP=wfdb-csharp
OLD_SWIG_CHECK=1
OLD_WFDB_CHECK=1


function swig_check_version () {
    DIR=$1
    THIS_SWIG_VERSION=`swig -version 2>&1 |grep "SWIG Version" | cut -d" " -f3`
    LAST_SWIG_VERSION=`grep "SWIG Version" ./$DIR/swig-version | cut -d" " -f3`
    
    THIS_SWIG_VERSION_MAJOR=`echo $THIS_SWIG_VERSION | cut -d. -f1`
    LAST_SWIG_VERSION_MAJOR=`echo $LAST_SWIG_VERSION | cut -d. -f1`
    
    THIS_SWIG_VERSION_MINOR=`echo $THIS_SWIG_VERSION | cut -d. -f2`
    LAST_SWIG_VERSION_MINOR=`echo $LAST_SWIG_VERSION | cut -d. -f2`
    
    THIS_SWIG_VERSION_REV=`echo $THIS_SWIG_VERSION | cut -d. -f3`
    LAST_SWIG_VERSION_REV=`echo $LAST_SWIG_VERSION | cut -d. -f3`
    

    ret=0
    if [ "$OLD_SWIG_CHECK" -eq "1" ]; then
	if [ "$THIS_SWIG_VERSION_MAJOR" -lt "$LAST_SWIG_VERSION_MAJOR" -o \
	    "$THIS_SWIG_VERSION_MINOR" -lt "$LAST_SWIG_VERSION_MINOR" -o \
	    "$THIS_SWIG_VERSION_REV" -lt "$LAST_SWIG_VERSION_REV" ]; then 
	    echo
	    echo "Error: you are attempting to regenerate the sources for $DIR"
	    echo "with an older version of swig then was previously used."
	    echo "Last generated with version $LAST_SWIG_VERSION"
	    echo "Your version is $THIS_SWIG_VERSION"
	    echo
	    echo "To overide use the -allow-old-swig switch."
	    ret=0
	else
	    ret=1
	fi
    else
	ret=1
    fi
    return $ret
}


function wfdb_check_version () {
    DIR=$1
    THIS_WFDB_VERSION=`wfdb-config --version`
    LAST_WFDB_VERSION=`cat ./$DIR/wfdb-version`
    
    THIS_WFDB_VERSION_MAJOR=`echo $THIS_WFDB_VERSION | cut -d. -f1`
    LAST_WFDB_VERSION_MAJOR=`echo $LAST_WFDB_VERSION | cut -d. -f1`
    
    THIS_WFDB_VERSION_MINOR=`echo $THIS_WFDB_VERSION | cut -d. -f2`
    LAST_WFDB_VERSION_MINOR=`echo $LAST_WFDB_VERSION | cut -d. -f2`
    
    THIS_WFDB_VERSION_REV=`echo $THIS_WFDB_VERSION | cut -d. -f3`
    LAST_WFDB_VERSION_REV=`echo $LAST_WFDB_VERSION | cut -d. -f3`
    
    ret=0
    if [ "$OLD_WFDB_CHECK" -eq "1" ]; then
	if [ "$THIS_WFDB_VERSION_MAJOR" -lt "$LAST_WFDB_VERSION_MAJOR" -o \
	    "$THIS_WFDB_VERSION_MINOR" -lt "$LAST_WFDB_VERSION_MINOR" -o \
	    "$THIS_WFDB_VERSION_REV" -lt "$LAST_WFDB_VERSION_REV" ]; then 
	    echo
	    echo "Error: you are attempting to regenerate the sources for $DIR"
	    echo "with an older version of wfdb then was previously used."
	    echo "Last generated with version $LAST_WFDB_VERSION"
	    echo "Your version is $THIS_WFDB_VERSION"
	    echo
	    echo "To overide use the -allow-old-wfdb switch."
	    ret=0
	else
	    ret=1
	fi
    else
	ret=1
    fi
    return $ret
}


if [ $# -lt 1 ]
then
    echo "
usage: $0 [options]
Options
    -java    generate the java interface sources
    -csharp  generate the csharp interface sources
    -perl    generate the perl interface soruces
    -python  generate the python interface soruces
    -all     generate all language interface sources
    -allow-old-swig generate with older version of swig
    -allow-old-wfdb generate with older version of wfdb
"
fi

for i in $*
do
  case $i in
      -java)   LANG="$LANG java"   ;;
      -csharp) LANG="$LANG csharp" ;;
      -perl)   LANG="$LANG perl"   ;;
      -python) LANG="$LANG python" ;;
      -all)    LANG="java csharp perl python" ;;
      -allow-old-swig) OLD_SWIG_CHECK=0 ;;
      -allow-old-wfdb) OLD_WFDB_CHECK=0 ;;
      *)        cat <<EOF
usage: $0 [options]
Options
    -java    generate the java interface sources
    -csharp   generate the csharp interface sources
    -perl    generate the perl interface soruces
    -python  generate the python interface soruces
    -all     generate all language interface sources
    -allow-old-swig generate with older version of swig
    -allow-old-wfdb generate with older version of wfdb
EOF
	  ;;
  esac
done


for l in $LANG; do
  
    case $l in
	java)
	    swig_check_version $WFDB_JAVA; SWIG_STATUS=$?
	    wfdb_check_version $WFDB_JAVA; WFDB_STATUS=$?
	    if [ "$SWIG_STATUS" -eq  "1" -a "$WFDB_STATUS" -eq  "1" ]; then
		$SWIG $INCDIR -java -package wfdb \
		    -outdir $WFDB_JAVA/src/wfdb \
		    -o $WFDB_JAVA/src/wfdb_java_wrap.c \
		    wfdb.i 		
		$SWIG -version &> ./$WFDB_JAVA/swig-version
		wfdb-config --version > ./$WFDB_JAVA/wfdb-version
	    fi
	    ;;
	csharp)
	    swig_check_version $WFDB_CSHARP; SWIG_STATUS=$?
	    wfdb_check_version $WFDB_CSHARP; WFDB_STATUS=$?
	    if [ "$SWIG_STATUS" -eq  "1" -a "$WFDB_STATUS" -eq  "1" ]; then
		$SWIG $INCDIR -csharp \
		    -namespace Wfdb \
		    -dllimport wfdbsharpglue \
		    -outdir $WFDB_CSHARP/src/ \
		    -o $WFDB_CSHARP/src/wfdb_csharp_wrap.c \
		    wfdb.i
		$SWIG -version &> ./$WFDB_CSHARP/swig-version
		wfdb-config --version > ./$WFDB_CSHARP/wfdb-version
	    fi
	    ;;
	perl)
	    swig_check_version $WFDB_PERL; SWIG_STATUS=$?
	    wfdb_check_version $WFDB_PERL; WFDB_STATUS=$?
	    if [ "$SWIG_STATUS" -eq  "1" -a "$WFDB_STATUS" -eq  "1" ]; then
		$SWIG $INCDIR -perl5 \
		    -outdir $WFDB_PERL/ \
		    -o $WFDB_PERL/wfdb_perl_wrap.c \
		    wfdb.i
		$SWIG -version &> ./$WFDB_PERL/swig-version
		wfdb-config --version > ./$WFDB_PERL/wfdb-version
	    fi
	    ;;
	python)
	    swig_check_version $WFDB_PYTHON; SWIG_STATUS=$?
	    wfdb_check_version $WFDB_PYTHON; WFDB_STATUS=$?
	    if [ "$SWIG_STATUS" -eq  "1" -a "$WFDB_STATUS" -eq  "1" ]; then
		$SWIG $INCDIR -python \
		    -outdir $WFDB_PYTHON/ \
		    -o $WFDB_PYTHON/wfdb_python_wrap.c \
		    wfdb.i
		$SWIG -version &> ./$WFDB_PYTHON/swig-version
		wfdb-config --version > ./$WFDB_PYTHON/wfdb-version
	    fi
	    ;;
    esac

done

